"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AWSElasticSearchQuery = void 0;
const BaseFilter_1 = require("./BaseFilter");
const ElasticSearchQuery_1 = require("./ElasticSearchQuery");
const GRANULARITY_TO_INTERVAL = {
    day: (date) => `DATE_FORMAT(${date}, 'yyyy-MM-dd 00:00:00.000')`,
    // eslint-disable-next-line no-unused-vars,@typescript-eslint/no-unused-vars
    week: (date) => { throw new Error('Week is unsupported'); },
    hour: (date) => `DATE_FORMAT(${date}, 'yyyy-MM-dd HH:00:00.000')`,
    minute: (date) => `DATE_FORMAT(${date}, 'yyyy-MM-dd HH:mm:00.000')`,
    second: (date) => `DATE_FORMAT(${date}, 'yyyy-MM-dd HH:mm:ss.000')`,
    month: (date) => `DATE_FORMAT(${date}, 'yyyy-MM-01 00:00:00.000')`,
    year: (date) => `DATE_FORMAT(${date}, 'yyyy-01-01 00:00:00.000')`
};
class AWSElasticSearchQueryFilter extends BaseFilter_1.BaseFilter {
    likeIgnoreCase(column, not, param, type) {
        const p = (!type || type === 'contains' || type === 'ends') ? '%' : '';
        const s = (!type || type === 'contains' || type === 'starts') ? '%' : '';
        return `${column}${not ? ' NOT' : ''} LIKE CONCAT('${p}', ${this.allocateParam(param)}, '${s}')`;
    }
}
class AWSElasticSearchQuery extends ElasticSearchQuery_1.ElasticSearchQuery {
    newFilter(filter) {
        return new AWSElasticSearchQueryFilter(this, filter);
    }
    subtractInterval(date, interval) {
        return `DATE_SUB(${date}, INTERVAL ${interval})`;
    }
    addInterval(date, interval) {
        return `DATE_ADD(${date}, INTERVAL ${interval})`;
    }
    timeGroupedColumn(granularity, dimension) {
        return GRANULARITY_TO_INTERVAL[granularity](dimension);
    }
    unixTimestampSql() {
        return 'EXTRACT(EPOCH FROM NOW())';
    }
}
exports.AWSElasticSearchQuery = AWSElasticSearchQuery;
//# sourceMappingURL=AWSElasticSearchQuery.js.map