/// <reference types="node" />
import vm from 'vm';
import { LRUCache } from 'lru-cache';
import { FileContent, SchemaFileRepository } from '@cubejs-backend/shared';
import { NativeInstance, PythonCtx } from '@cubejs-backend/native';
import { ErrorReporter, ErrorReporterOptions } from './ErrorReporter';
import { CubeSymbols } from './CubeSymbols';
import { ViewCompilationGate } from './ViewCompilationGate';
import { TranspilerInterface } from './transpilers';
import { CompilerInterface } from './PrepareCompiler';
import { YamlCompiler } from './YamlCompiler';
import { CubeDictionary } from './CubeDictionary';
import { CompilerCache } from './CompilerCache';
export type DataSchemaCompilerOptions = {
    compilerCache: CompilerCache;
    omitErrors?: boolean;
    extensions?: Record<string, any>;
    filesToCompile?: string[];
    nativeInstance: NativeInstance;
    cubeFactory: Function;
    cubeDictionary: CubeDictionary;
    cubeSymbols: CubeSymbols;
    cubeCompilers?: CompilerInterface[];
    contextCompilers?: CompilerInterface[];
    transpilers?: TranspilerInterface[];
    viewCompilers?: CompilerInterface[];
    viewCompilationGate: ViewCompilationGate;
    cubeNameCompilers?: CompilerInterface[];
    preTranspileCubeCompilers?: CompilerInterface[];
    yamlCompiler: YamlCompiler;
    errorReport?: ErrorReporterOptions;
    compilerId?: string;
    standalone?: boolean;
    compileContext?: any;
    allowNodeRequire?: boolean;
    compiledScriptCache: LRUCache<string, vm.Script>;
};
export type TranspileOptions = {
    cubeNames?: string[];
    cubeSymbols?: Record<string, Record<string, boolean>>;
    contextSymbols?: Record<string, string>;
    transpilerNames?: string[];
    compilerId?: string;
    stage?: 0 | 1 | 2 | 3;
};
export type CompileStage = 0 | 1 | 2 | 3;
export declare class DataSchemaCompiler {
    private readonly repository;
    private readonly cubeCompilers;
    private readonly contextCompilers;
    private readonly transpilers;
    private readonly viewCompilers;
    private readonly preTranspileCubeCompilers;
    private readonly viewCompilationGate;
    private readonly cubeNameCompilers;
    private readonly extensions;
    private readonly cubeDictionary;
    private readonly cubeSymbols;
    private readonly cubeFactory;
    private readonly filesToCompile;
    private readonly omitErrors;
    private readonly allowNodeRequire;
    private readonly compilerCache;
    private readonly compileContext;
    private errorReportOptions;
    private errorsReporter;
    private readonly standalone;
    private readonly nativeInstance;
    private readonly yamlCompiler;
    private pythonContext;
    private workerPool;
    private readonly compilerId;
    private readonly compiledScriptCache;
    compilePromise: any;
    private currentQuery;
    constructor(repository: SchemaFileRepository, options: DataSchemaCompilerOptions);
    compileObjects(compileServices: any, objects: any, errorsReport: ErrorReporter): any;
    protected loadPythonContext(files: any, nsFileName: any): Promise<PythonCtx>;
    protected doCompile(): Promise<void>;
    compile(): any;
    private transpileFile;
    /**
     * Right now it is used only for transpilation in native,
     * so no checks for transpilation type inside this method
     */
    private transpileJsFilesBulk;
    private transpileJsFile;
    withQuery(query: any, fn: any): any;
    contextQuery(): any;
    private compileCubeFiles;
    throwIfAnyErrors(): void;
    private compileFile;
    private getJsScript;
    compileJsFile(file: FileContent, errorsReport: ErrorReporter, cubes: any, contexts: any, exports: any, asyncModules: any, toCompile: any, compiledFiles: any, { doSyntaxCheck }?: {
        doSyntaxCheck: boolean;
    }): void;
    private cloneCompileContextWithGetterAlias;
    private standaloneCompileContextProxy;
    private resolveModuleFile;
    private readModuleFile;
    private isWhiteListedPackage;
}
//# sourceMappingURL=DataSchemaCompiler.d.ts.map